@@ -1,10 +1,10 @@
-!!<fortpy version="1.2.18" />
+!!<fortpy version="1.3.7" />
 !!<summary>Provides an interface for saving the values of multiple variable
 !!types using a single call. Used as part of the FORTPY unit testing framework.</summary>
 module fortpy
   implicit none
   private
-  public pysave, dp, sp, si, li, fpy_linevalue_count, fpy_newunit, pysave_integer_li, &
+  public pysave, fdp, fsp, fsi, fli, fpy_linevalue_count, fpy_newunit, pysave_integer_li, &
        fpy_value_count, fpy_period_join_indices, fpy_linevalue_count_all
 
   !!<member name="fileunit">I/O unit for the file to write the output to.</member>
@@ -13,10 +13,10 @@ module fortpy
   !!already been seeded for this program execution.</member>
   logical :: seeded
 
-  integer, parameter:: dp=selected_real_kind(15,307)
-  integer, parameter:: sp=selected_real_kind(6,37)
-  integer, parameter:: si=selected_int_kind(1) ! very short integer -10..10 range
-  integer, parameter:: li=selected_int_kind(18) ! Big integer -10^18..10^18 range
+  integer, parameter:: fdp=selected_real_kind(15,307)
+  integer, parameter:: fsp=selected_real_kind(6,37)
+  integer, parameter:: fsi=selected_int_kind(1) ! very short integer -10..10 range
+  integer, parameter:: fli=selected_int_kind(18) ! Big integer -10^18..10^18 range
 
   !!<summary>Provides a single call interface for integer and real data types
   !!for single values, 1D and 2D arrays. Also handles outputting true/false for
@@ -71,22 +71,22 @@ contains
   end subroutine fpy_period_join_indices
 
   logical function in_range_real_2d(variable, min, max)
-    real(dp), intent(in) :: variable(:,:)
-    real(dp), intent(in) :: min, max
+    real(fdp), intent(in) :: variable(:,:)
+    real(fdp), intent(in) :: min, max
     in_range_real_2d = any(variable .ge. min .and. variable .le. max)
     return
   end function in_range_real_2d
 
   logical function in_range_real_1d(variable, min, max)
-    real(dp), intent(in) :: variable(:)
-    real(dp), intent(in) :: min, max
+    real(fdp), intent(in) :: variable(:)
+    real(fdp), intent(in) :: min, max
     in_range_real_1d = any(variable .ge. min .and. variable .le. max)
     return
   end function in_range_real_1d
 
   logical function in_range_real(variable, min, max)
-    real(dp), intent(in) :: variable
-    real(dp), intent(in) :: min, max
+    real(fdp), intent(in) :: variable
+    real(fdp), intent(in) :: min, max
     in_range_real = (variable .ge. min .and. variable .le. max)
     return
   end function in_range_real
@@ -113,8 +113,8 @@ contains
   end function in_range_integer
 
   subroutine random_real_2d(variable, min, max)
-    real(dp), intent(out) :: variable(:,:)
-    real(dp), intent(in) :: min, max
+    real(fdp), intent(out) :: variable(:,:)
+    real(fdp), intent(in) :: min, max
     integer :: r, c, i, j
 
     r = size(variable, 1)
@@ -127,8 +127,8 @@ contains
   end subroutine random_real_2d
 
   subroutine random_real_1d(variable, min, max)
-    real(dp), intent(out) :: variable(:)
-    real(dp), intent(in) :: min, max
+    real(fdp), intent(out) :: variable(:)
+    real(fdp), intent(in) :: min, max
     integer :: r, i
 
     r = size(variable, 1)
@@ -138,9 +138,9 @@ contains
   end subroutine random_real_1d
 
    subroutine random_real(variable, min, max)
-    real(dp), intent(out) :: variable
-    real(dp), intent(in) :: min, max
-    real(dp) :: x
+    real(fdp), intent(out) :: variable
+    real(fdp), intent(in) :: min, max
+    real(fdp) :: x
     !Since we only get real numbers in [0, 1], we have to set the value to be 
     !in the range manually.
     call random_number(x)    
@@ -175,7 +175,7 @@ contains
   subroutine random_integer(variable, min, max)
     integer, intent(out) :: variable
     integer, intent(in) :: min, max
-    real(dp) :: x
+    real(fdp) :: x
     !Since we only get real numbers, we have to set the value to be in the range
     !and then turn it to an integer.
     call random_number(x)    
@@ -241,7 +241,7 @@ contains
   end subroutine pysave_integer_2d
 
   subroutine pysave_integer_li(variable, filename, n)
-    integer(li), intent(in) :: variable
+    integer(fli), intent(in) :: variable
     integer, intent(in) :: n
     character(n), intent(in) :: filename
 
@@ -252,7 +252,7 @@ contains
   end subroutine pysave_integer_li
 
   subroutine pysave_integer_1d_li(variable, filename, n)
-    integer(li), intent(in) :: variable(:)
+    integer(fli), intent(in) :: variable(:)
     integer, intent(in) :: n
     character(n), intent(in) :: filename
     integer :: c, i
@@ -267,7 +267,7 @@ contains
   end subroutine pysave_integer_1d_li
 
   subroutine pysave_integer_2d_li(variable, filename, n)
-    integer(li), intent(in) :: variable(:,:)
+    integer(fli), intent(in) :: variable(:,:)
     integer, intent(in) :: n
     character(n), intent(in) :: filename
     character(20) :: FMT
@@ -287,7 +287,7 @@ contains
   end subroutine pysave_integer_2d_li
 
   subroutine pysave_real(variable, filename, n)
-    real(dp), intent(in) :: variable
+    real(fdp), intent(in) :: variable
     integer, intent(in) :: n
     character(n), intent(in) :: filename
 
@@ -298,7 +298,7 @@ contains
   end subroutine pysave_real
 
   subroutine pysave_real_1d(variable, filename, n)
-    real(dp), intent(in) :: variable(:)
+    real(fdp), intent(in) :: variable(:)
     integer, intent(in) :: n
     character(n), intent(in) :: filename
     integer :: c, i
@@ -313,7 +313,7 @@ contains
   end subroutine pysave_real_1d
 
   subroutine pysave_real_2d(variable, filename, n)
-    real(dp), intent(in) :: variable(:,:)
+    real(fdp), intent(in) :: variable(:,:)
     integer, intent(in) :: n
     character(n), intent(in) :: filename
     character(20) :: FMT
